<?php

namespace Drupal\Tests\tmgmt_extension_suit\Kernel;

use Drupal\Tests\tmgmt\Kernel\TMGMTKernelTestBase;

// Note we have to disable the SYMFONY_DEPRECATIONS_HELPER to ensure deprecation
// notices are not triggered.
// TODO: remove this and fix all the deprecations before Drupal 9.0.0.
putenv('SYMFONY_DEPRECATIONS_HELPER=disabled');

/**
 * TMGMT Extension Suit kernel test base class.
 *
 * @group tmgmt_extension_suit
 */
class BaseTest extends TMGMTKernelTestBase {

  public static $modules = ['tmgmt_extension_suit'];

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->installConfig(['tmgmt_extension_suit']);
  }

  /**
   * Test tmgmt_extension_suit_is_add_to_check_status_cron_run_needed().
   */
  public function testIsAddToCheckStatusQueueFunction() {
    // Check default value.
    $three_days_in_seconds = 10800;
    $this->assertEquals(\Drupal::config('tmgmt_extension_suit.settings')->get('interval'), $three_days_in_seconds);

    // Last cron run happened 5 seconds ago - no need to add items to the queue.
    $request_time = \Drupal::time()->getRequestTime();
    \Drupal::state()->set('system.cron_last', $request_time - 5);

    $this->assertEquals(
      tmgmt_extension_suit_is_add_to_check_status_cron_run_needed(),
      FALSE
    );

    // Last cron run happened 3 days ago - no need to add items to the queue.
    \Drupal::state()->set('system.cron_last', $request_time - $three_days_in_seconds);

    $this->assertEquals(
      tmgmt_extension_suit_is_add_to_check_status_cron_run_needed(),
      FALSE
    );

    // Last cron run happened more than 3 days ago - add items to the queue.
    \Drupal::state()->set('system.cron_last', $request_time - $three_days_in_seconds - 5);

    $this->assertEquals(
      tmgmt_extension_suit_is_add_to_check_status_cron_run_needed(),
      TRUE
    );

    // Change interval to 10 seconds.
    \Drupal::configFactory()
      ->getEditable('tmgmt_extension_suit.settings')
      ->set('interval', 10)
      ->save(TRUE);

    // Last cron run happened 5 seconds ago - no need to add items to the queue.
    \Drupal::state()->set('system.cron_last', $request_time - 5);

    $this->assertEquals(
      tmgmt_extension_suit_is_add_to_check_status_cron_run_needed(),
      FALSE
    );

    // Last cron run happened 10 seconds ago - no need to add items to the
    // queue.
    \Drupal::state()->set('system.cron_last', $request_time - 10);

    $this->assertEquals(
      tmgmt_extension_suit_is_add_to_check_status_cron_run_needed(),
      FALSE
    );

    // Last cron run happened more than 10 seconds ago - add items to the queue.
    \Drupal::state()->set('system.cron_last', $request_time - 10 - 5);

    $this->assertEquals(
      tmgmt_extension_suit_is_add_to_check_status_cron_run_needed(),
      TRUE
    );
  }
}
